@@ -11,6 +11,8 @@ class EFO(EntityTable):
     """Experimental Factor Ontology.
 
     https://www.ebi.ac.uk/ols/ontologies/efo
+
+    Also see: `bionty.EntityTable <https://lamin.ai/docs/bionty/bionty.entitytable>`__
     """
 
     def __init__(self, id=None, reload=False) -> None:
@@ -36,41 +38,49 @@ class EFO(EntityTable):
         return df
 
     @cached_property
-    def ontology(self):
+    def ontology(self) -> Ontology:
         """Cell ontology."""
-        url = "http://www.ebi.ac.uk/efo/efo.owl"
         localpath = settings.dynamicdir / "efo.obo"
-        url = url if ((not localpath.exists()) or (self._reload)) else None
+        url = (
+            "http://www.ebi.ac.uk/efo/efo.owl"
+            if ((not localpath.exists()) or (self._reload))
+            else None
+        )
         ontology_ = Ontology(handle=localpath, url=url, prefix=self._prefix)
         if url is not None:
             ontology_.write_obo()
         return ontology_
 
     @cached_property
-    def assay(self):
-        """Assays OBI:0000070."""
+    def assay(self) -> list:
+        """Assays."""
+        # OBI:0000070
         return self.ontology._list_subclasses(self._readout_terms["assay"])
 
     @cached_property
-    def assay_by_molecule(self):
-        """Assays by molecule EFO:0002772."""
+    def assay_by_molecule(self) -> list:
+        """Assays by molecule."""
+        # EFO:0002772
         return self.ontology._list_subclasses(self._readout_terms["assay_by_molecule"])
 
     @cached_property
-    def assay_by_instrument(self):
-        """Assays by instrument EFO:0002773."""
+    def assay_by_instrument(self) -> list:
+        """Assays by instrument."""
+        # EFO:0002773
         return self.ontology._list_subclasses(
             self._readout_terms["assay_by_instrument"]
         )
 
     @cached_property
-    def assay_by_sequencer(self):
-        """Assay by sequencer EFO:0003740."""
+    def assay_by_sequencer(self) -> list:
+        """Assay by sequencer."""
+        # EFO:0003740
         return self.ontology._list_subclasses(self._readout_terms["assay_by_sequencer"])
 
     @cached_property
-    def measurement(self):
-        """Measurement EFO:0001444."""
+    def measurement(self) -> list:
+        """Measurement."""
+        # EFO:0001444
         return self.ontology._list_subclasses(self._readout_terms["measurement"])
 
     def _create_df_from_ontology(self) -> pd.DataFrame:
@@ -84,7 +94,7 @@ class EFO(EntityTable):
         ).set_index("id")
 
     @check_datasetdir_exists
-    def _download_df(self):
+    def _download_df(self) -> None:
         from urllib.request import urlretrieve
 
         urlretrieve(
@@ -92,7 +102,7 @@ class EFO(EntityTable):
             self._filepath,
         )
 
-    def parse_readout(self, term_id):
+    def parse_readout(self, term_id) -> dict:
         """Parse readout attributes from EFO."""
 
         def _list_to_str(lst: list):
@@ -126,6 +136,6 @@ class EFO(EntityTable):
         return readout
 
 
-def readout(efo_id: str):
+def readout(efo_id: str) -> dict:
     """Get readout attributes from EFO id."""
     return EFO().parse_readout(term_id=efo_id)
